{% extends 'layout/checkout.html.twig' %}

{% block title %}{{ 'checkout_design.payment_return'|trans }}{% endblock %}

{% block meta %}
    <meta name="robots" content="noindex,nofollow">
{% endblock meta %}

{% block main %}
    <section class="theme-checkout-status">
        <div class="theme-checkout-status__card">
            <p class="theme-checkout-eyebrow">{{ 'checkout_design.payment_return'|trans }}</p>
            <h1>{{ msg }}</h1>
            {% if error %}
                <p class="theme-checkout-status__error">{{ error }}</p>
            {% endif %}
            <div class="theme-checkout-actions">
                <a href="{{ path('shop') }}" class="theme-button-fill theme-hover-link-effect">
                    {{ 'checkout_design.back_shop'|trans }}
                </a>
            </div>
        </div>
    </section>
{% endblock %}
