{% props variant = 'logo', alt = '' %}

{% set sources = {
    logo: 'images/BM_clr_glossy.svg',
    pictogram_color: 'images/picto_clr.svg',
    pictogram_light: 'images/picto_blc.svg'
} %}

<img
    src="{{ asset(viti_theme_asset(sources[variant]|default(sources.logo))) }}"
    alt="{{ alt }}"
    {{ attributes }}
>
