{% form_theme form with app_form_themes() only %}

<div {{ attributes }}>
    {{ form_start(form, {
        attr: {
            class: 'theme-auth-form',
            'data-model': 'norender|*',
            'data-action': 'live#action:prevent',
            'data-live-action-param': 'submitLogin',
            novalidate: 'true'
        }
    }) }}
        <div class="theme-form-field">
            {{ form_label(form.email) }}
            {{ form_widget(form.email, {'attr': { class: 'theme-form-input' }}) }}
            <div class="theme-form-error">{{ form_errors(form.email) }}</div>
        </div>
        <div class="theme-form-field">
            {{ form_label(form.password) }}
            {{ form_widget(form.password, {'attr': { class: 'theme-form-input' }}) }}
            <div class="theme-form-error">{{ form_errors(form.password) }}</div>
        </div>
        <div class="theme-form-line">
            <label class="theme-checkbox">
                {{ form_widget(form.rememberMe, {'attr': {'class': 'theme-checkbox__input'}}) }}
                <span>{{ form.rememberMe.vars.label|trans({}, form.rememberMe.vars.translation_domain) }}</span>
            </label>
            <a href="{{ path('app_forgot_password') }}" class="theme-inline-link" data-turbo-frame="account-auth-frame">{{ 'security.login.forgot_password'|trans }}</a>
        </div>
        {% if form.captcha is defined %}
            <div class="theme-form-field">{{ form_row(form.captcha) }}</div>
        {% endif %}
        <button
            type="submit"
            title="{{ 'security.login.submit'|trans }}"
            class="theme-form-button theme-form-button--fill"
        >
            {{ 'security.login.submit'|trans }}
        </button>
        <div class="hidden">{{ form_rest(form) }}</div>
    {{ form_end(form) }}
</div>
