<article data-information-block class="theme-shop-information-card">
    <div class="theme-shop-information-card__header">
        {% if block.image and block.image.path %}
            <div class="theme-shop-information-card__image">
                <twig:Image
                    alt="{{ block.title ?? 'Information' }}"
                    class="h-full w-full"
                    img:class="h-full w-full object-contain"
                    lazy="{{ false }}"
                    quality="{{ 70 }}"
                    responsive="{{ false }}"
                    path="{{ block.image.path|image_path }}"
                    imageWidth="96"
                    imageHeight="96"
                />
            </div>
        {% endif %}
        <div>
            <h3>{{ block.title }}</h3>
            <span></span>
        </div>
    </div>

    <div class="theme-shop-information-card__description">
        {{ block.description|replace({
            '\\<br\\>': '<br>',
            '\\<br/\\>': '<br/>',
            '\\<br /\\>': '<br />',
        })|raw }}
    </div>

    {% if block.actionType == constant('CpCreation\\VitiCore\\Shop\\Model\\InformationBlock::ACTION_LINK') and block.buttonLabel and block.buttonUrl %}
        <a href="{{ block.buttonUrl }}" class="theme-button-fill theme-hover-link-effect">
            {{ block.buttonLabel }}
        </a>
    {% elseif block.actionType == constant('CpCreation\\VitiCore\\Shop\\Model\\InformationBlock::ACTION_MODAL') and block.buttonLabel and block.hasModalContent %}
        <button
            type="button"
            class="theme-button-fill theme-hover-link-effect"
            data-action="live#action"
            data-live-action-param="showInformationModal"
            data-live-information-block-id-param="{{ block.id.toString }}">
            {{ block.buttonLabel }}
        </button>
    {% endif %}
</article>
