export default function menu() {
    return {
        open: false,
        toggle() {
            this.open = !this.open;
        },
        openCart() {
            this.open = false;
            window.dispatchEvent(new CustomEvent('menu-open-cart'));
        },
    };
}
