{% extends 'base.html.twig' %}

{% block title %}{{ 'contact.title'|trans({}, 'meta') }}{% endblock %}

{% block meta %}
    {{ include('partials/seo.html.twig', {
        title_key: 'contact.title',
        description_key: 'contact.description',
        robots: 'index,follow'
    }) }}
{% endblock %}

{% block page_hero %}
    {% set hero_image_path %}{% block hero_image %}{{ viti_theme_asset('images/headers/header-contact.jpg') }}{% endblock %}{% endset %}
    {% include 'partials/_hero.html.twig' with {
        page_key: 'contact',
        target_id: 'contact',
        image: 'images/headers/header-contact.jpg',
        image_path: hero_image_path|trim,
        image_alt: 'background-header.contact'
    } %}
{% endblock %}

{% block main %}
    <section id="contact" class="theme-page theme-contact-page">
        <div class="theme-container">
            <div class="theme-contact-content">
                <p class="theme-intro">{{ 'contact.intro'|trans }}</p>
                <p>{{ 'contact.form.text_intro'|trans|raw }}</p>
                <twig:site:ContactForm />
            </div>
        </div>
    </section>
{% endblock %}
