{% extends 'layout/checkout.html.twig' %}

{% block title %}{{ 'checkout_design.payment_unconfirmed_title'|trans }}{% endblock %}

{% block meta %}
    <meta name="robots" content="noindex,nofollow">
{% endblock meta %}

{% block main %}
    <section class="theme-checkout-status">
        <div class="theme-checkout-status__card">
            <p class="theme-checkout-eyebrow">{{ 'checkout_design.payment_unconfirmed_badge'|trans }}</p>
            <h1>{{ 'checkout_design.payment_unconfirmed_title'|trans }}</h1>
            <p>{{ 'checkout_design.payment_unconfirmed_notice'|trans }}</p>
            <p class="theme-checkout-status__reference">
                {{ 'checkout_design.payment_pending_reference'|trans({ '%reference%': cart.token }) }}
            </p>
            <div class="theme-checkout-actions">
                {% if contact_url %}
                    <a href="{{ contact_url }}" class="theme-button-fill theme-hover-link-effect">
                        {{ 'checkout_design.payment_unconfirmed_contact_button'|trans }}
                    </a>
                {% elseif contact_email %}
                    <a href="mailto:{{ contact_email }}?subject={{ 'checkout_design.payment_unconfirmed_email_subject'|trans({ '%reference%': cart.token })|url_encode }}"
                       class="theme-button-fill theme-hover-link-effect">
                        {{ contact_email }}
                    </a>
                {% else %}
                    <a href="{{ path('shop') }}" class="theme-button-fill theme-hover-link-effect">
                        {{ 'checkout_design.back_shop'|trans }}
                    </a>
                {% endif %}
            </div>
        </div>
    </section>
{% endblock %}
