{% form_theme form with app_form_themes() only %}

<div {{ attributes }}>
{{ form_start(form, {
    attr: {
        class: 'theme-contact-form theme-form',
        id: 'contactForm',
        'data-action': 'live#action:prevent',
        'data-live-action-param': 'submitContact',
        'data-model': 'norender|*',
        novalidate: 'true'
    }
}) }}
    {{ form_errors(form) }}
    <div class="theme-form-group">
        {{ form_widget(form.lastname, { attr: { placeholder: 'field.lastname'|trans({}, 'form') } }) }}
        {{ form_errors(form.lastname) }}
    </div>
    <div class="theme-form-group">
        {{ form_widget(form.firstname, { attr: { placeholder: 'field.firstname'|trans({}, 'form') } }) }}
        {{ form_errors(form.firstname) }}
    </div>
    <div class="theme-form-group">
        {{ form_widget(form.email, { attr: { placeholder: 'field.email'|trans({}, 'form') } }) }}
        {{ form_errors(form.email) }}
    </div>
    <div class="theme-form-group">
        {{ form_widget(form.phone, { attr: { placeholder: 'field.number'|trans({}, 'form') } }) }}
        {{ form_errors(form.phone) }}
    </div>
    <div class="theme-form-group">
        {{ form_widget(form.object, { attr: { placeholder: 'field.subject'|trans({}, 'form') } }) }}
        {{ form_errors(form.object) }}
    </div>
    <div class="theme-form-group">
        {{ form_widget(form.message, { attr: { placeholder: 'field.message'|trans({}, 'form') } }) }}
        {{ form_errors(form.message) }}
    </div>
    <div class="theme-form-group theme-contact-captcha">
        {{ form_row(form.captcha) }}
    </div>
    <div class="theme-form-group theme-contact-submit">
        {{ form_rest(form) }}
        <button class="theme-button-border theme-hover-link-effect" type="submit" data-loading="addAttribute(disabled)">
            <span data-loading="hide">{{ 'contact.form.submit'|trans({}, 'messages') }}</span>
            <span data-loading="show">{{ 'submit'|trans({}, 'form') }}</span>
        </button>
    </div>
{{ form_end(form) }}
</div>
