{% extends 'base.html.twig' %}

{% set pageTitle = 'marketing.review.policy.page_title'|trans %}
{% set pageDescription = 'marketing.review.policy.intro'|trans %}

{% block title %}{{ pageTitle }}{% endblock %}

{% block meta %}
    {{ include('partials/seo.html.twig', {
        title_key: 'marketing.review.policy.page_title',
        description_key: 'marketing.review.policy.intro',
        title: pageTitle,
        description: pageDescription,
        robots: 'index,follow'
    }) }}
{% endblock %}

{% block header %}
    {{ component('announcement:Banner') }}
{% endblock %}

{% block main %}
    <header class="theme-product-header">
        {% include 'partials/_nav.html.twig' %}
    </header>
    <article class="theme-review-page theme-review-policy">
        <div class="theme-container theme-review-page__container">
            <header class="theme-review-page__header">
                <h1>{{ 'marketing.review.policy.heading'|trans }}</h1>
                <p>{{ 'marketing.review.policy.intro'|trans }}</p>
            </header>

            <div class="theme-review-policy__sections">
                <section>
                    <h2>{{ 'marketing.review.policy.collection.title'|trans }}</h2>
                    <p>{{ 'marketing.review.policy.collection.text'|trans }}</p>
                </section>

                <section>
                    <h2>{{ 'marketing.review.policy.verified.title'|trans }}</h2>
                    <p>{{ 'marketing.review.policy.verified.text'|trans }}</p>
                </section>

                <section>
                    <h2>{{ 'marketing.review.policy.control.title'|trans }}</h2>
                    <p>{{ (moderation_enabled ? 'marketing.review.policy.control.enabled' : 'marketing.review.policy.control.disabled')|trans }}</p>
                    <p>{{ 'marketing.review.policy.control.contact'|trans }}</p>
                </section>

                <section>
                    <h2>{{ 'marketing.review.policy.neutrality.title'|trans }}</h2>
                    <p>{{ 'marketing.review.policy.neutrality.text'|trans }}</p>
                    <p>{{ 'marketing.review.policy.neutrality.example'|trans }}</p>
                </section>

                <section>
                    <h2>{{ 'marketing.review.policy.refusal.title'|trans }}</h2>
                    <p>{{ 'marketing.review.policy.refusal.intro'|trans }}</p>
                    <ul>
                        <li>{{ 'marketing.review.policy.refusal.illegal'|trans }}</li>
                        <li>{{ 'marketing.review.policy.refusal.personal_data'|trans }}</li>
                        <li>{{ 'marketing.review.policy.refusal.off_topic'|trans }}</li>
                        <li>{{ 'marketing.review.policy.refusal.spam'|trans }}</li>
                        <li>{{ 'marketing.review.policy.refusal.fraud'|trans }}</li>
                        <li>{{ 'marketing.review.policy.refusal.incomprehensible'|trans }}</li>
                    </ul>
                    <p>{{ 'marketing.review.policy.refusal.notice'|trans }}</p>
                </section>

                <section>
                    <h2>{{ 'marketing.review.policy.publication.title'|trans }}</h2>
                    <p>{{ 'marketing.review.policy.publication.text'|trans({
                        '%publication_days%': constant('CpCreation\\VitiCore\\Marketing\\ReviewPublicationPolicy::MAX_PUBLICATION_DELAY_DAYS'),
                        '%retention_years%': constant('CpCreation\\VitiCore\\Marketing\\ReviewPublicationPolicy::PUBLIC_RETENTION_YEARS')
                    }) }}</p>
                    <p>{{ 'marketing.review.policy.publication.sort'|trans }}</p>
                    <p>{{ 'marketing.review.policy.publication.purge'|trans({
                        '%grace_days%': constant('CpCreation\\VitiCore\\Marketing\\ReviewPublicationPolicy::UNUSED_INVITATION_GRACE_DAYS'),
                        '%retention_years%': constant('CpCreation\\VitiCore\\Marketing\\ReviewPublicationPolicy::REVIEW_DATA_RETENTION_YEARS')
                    }) }}</p>
                </section>

                <section>
                    <h2>{{ 'marketing.review.policy.compensation.title'|trans }}</h2>
                    <p>{{ 'marketing.review.policy.compensation.text'|trans }}</p>
                </section>

                <section>
                    <h2>{{ 'marketing.review.policy.changes.title'|trans }}</h2>
                    <p>{{ 'marketing.review.policy.changes.text'|trans }}</p>
                </section>

                <section>
                    <h2>{{ 'marketing.review.policy.reply.title'|trans }}</h2>
                    <p>{{ 'marketing.review.policy.reply.text'|trans }}</p>
                </section>

                {% if policy_additional_content|default('')|striptags|trim is not empty %}
                    <section>
                        <h2>{{ 'marketing.review.policy.additional.title'|trans }}</h2>
                        <div>{{ policy_additional_content|raw }}</div>
                    </section>
                {% endif %}

                <section>
                    <h2>{{ 'marketing.review.policy.certification.title'|trans }}</h2>
                    <p>{{ 'marketing.review.policy.certification.text'|trans }}</p>
                </section>
            </div>
        </div>
    </article>
{% endblock %}
