{% extends 'base.html.twig' %}

{% block title %}{{ 'security.forgot_password_pending.title'|trans({}, 'meta') }}{% endblock %}

{% block meta %}
    <meta name="robots" content="noindex,nofollow">
    <meta name="description" lang="{{ app.request.locale }}" content="{{ 'security.forgot_password_pending.description'|trans({}, 'meta') }}">
{% endblock meta %}

{% block main %}
    <section id="account-auth" class="theme-page theme-auth-page">
        <turbo-frame id="account-auth-frame" class="theme-auth-frame" data-turbo-action="advance">
            <div class="theme-container">
                <article class="theme-auth-card theme-auth-card--single">
                    <div class="theme-auth-card__heading">
                        <p class="theme-eyebrow">{{ 'security.forgot_password_pending.eyebrow'|trans }}</p>
                        <h2>{{ 'security.forgot_password_pending.heading'|trans }}</h2>
                    </div>
                    <div class="theme-richtext">
                        <p>{{ 'security.forgot_password_pending.message_prefix'|trans }}{% if reset_pending_email %} <strong>{{ reset_pending_email }}</strong>{% endif %}, {{ 'security.forgot_password_pending.message_suffix'|trans }}</p>
                        <p>{{ 'security.forgot_password_pending.expiry'|trans }}</p>
                        <p>{{ 'security.forgot_password_pending.spam_notice'|trans }}</p>
                    </div>
                    <div class="theme-form-actions">
                        <a href="{{ path('app_login') }}" class="theme-button-fill theme-hover-link-effect" data-turbo-frame="account-auth-frame">
                            {{ 'security.back_to_login'|trans }}
                        </a>
                    </div>
                </article>
            </div>
        </turbo-frame>
    </section>
{% endblock %}
