{% if template %}
    {% include template with { vacation: this } only %}
{% elseif this.active and config.vacation|default('')|striptags|trim is not empty %}
    <section {{ attributes.defaults({ class: 'theme-shop-vacation' }) }} role="status">
        {{ config.vacation|raw }}
    </section>
{% endif %}
