{% set contact = this.contact %}

{% if contact %}
    <div {{ attributes.defaults({ class: 'theme-contact-actions' }) }}>
        {% if contact.emailToMessage or contact.emailFrom %}
            <a class="theme-button-fill theme-hover-link-effect" href="mailto:{{ contact.emailToMessage ?: contact.emailFrom }}" title="{{ 'contact.balise'|trans({}, 'meta') }}">
                {{ 'homepage.presentation-contact-button_2'|trans }}
            </a>
        {% endif %}

        {% if contact.phone1 %}
            <a class="theme-button-stroke theme-hover-link-effect" href="tel:{{ contact.phone1 }}" title="{{ 'balise.contact.tel'|trans({}, 'meta') }}">
                {{ contact.phone1 }}
            </a>
        {% endif %}
    </div>
{% endif %}
