@theme {
    --color-theme-gold: #d3ad74;
    --color-theme-gold-soft: #f4d49d;
    --color-theme-gray: #6b6b6a;
    --color-theme-dark: #3c3c3b;
    --color-theme-black: #141414;
    --color-theme-white: #ffffff;
    --color-accent: #d3ad74;
    --color-accent-soft: #f4d49d;
    --color-page: #141414;
    --color-surface: #ffffff;
    --color-foreground: #141414;
    --color-on-foreground: #ffffff;
    --color-primary: #ffffff;
    --color-primary-container: #3c3c3b;
    --color-secondary: #d3ad74;
    --color-background: #141414;
    --color-surface-container: #252524;
    --color-surface-container-low: #1a1a19;
    --color-surface-container-high: #30302f;
    --color-surface-container-highest: #3c3c3b;
    --color-surface-variant: #30302f;
    --color-on-surface-variant: #f4f0ea;
    --color-outline: #d3ad74;
    --color-primary-fixed: #d3ad74;
    --color-primary-fixed-dim: #b88f55;
    --color-secondary-fixed: #f4d49d;
    --font-serif: "Museo Slab", museo-slab, Georgia, serif;
    --font-sans: "Roboto", Arial, sans-serif;
    --font-display: "Libre Bodoni", serif;
    --font-body: "Libre Franklin", sans-serif;
    --font-label: "Libre Franklin", sans-serif;
}
