<!DOCTYPE html>
<html lang="{{ app.request.locale }}">
<head>
    {% set head_title %}{% block title %}{{ 'company'|trans }}{% endblock %}{% endset %}
    {% set head_meta %}{% block meta %}{% endblock %}{% endset %}
    {% set head_stylesheets %}{% block stylesheets %}{% endblock %}{% endset %}
    {% set head_javascripts %}{% block javascripts %}{% endblock %}{% endset %}
    {{ include('partials/head.html.twig', {
        head_title: head_title,
        head_meta: head_meta,
        head_stylesheets: head_stylesheets,
        head_javascripts: head_javascripts
    }) }}
    <link rel="apple-touch-icon" sizes="180x180" href="{{ asset(viti_theme_asset('images/favicon/apple-touch-icon.png')) }}">
    <link rel="icon" type="image/png" sizes="32x32" href="{{ asset(viti_theme_asset('images/favicon/favicon-32x32.png')) }}">
    <link rel="icon" type="image/png" sizes="16x16" href="{{ asset(viti_theme_asset('images/favicon/favicon-16x16.png')) }}">
    <link rel="manifest" href="{{ asset(viti_theme_asset('images/favicon/site.webmanifest')) }}">
    <link rel="mask-icon" href="{{ asset(viti_theme_asset('images/favicon/safari-pinned-tab.svg')) }}" color="#8c827a">
    <meta name="msapplication-TileColor" content="#8c827a">
    <meta name="theme-color" content="#ffffff">
    <link rel="icon" type="image/x-icon" href="{{ asset(viti_theme_asset('images/favicon/favicon.ico')) }}">
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Josefin+Sans:wght@100;300;400&family=Roboto:ital,wght@0,100;0,400;0,500;0,700;1,400&display=swap">
    <link rel="stylesheet" href="https://use.typekit.net/wup2esi.css">
</head>
{% set canonical_route = app.request.attributes.get('_canonical_route')|default(app.request.get('_route')|default('')) %}
<body class="{{ canonical_route }} {{ app.request.get('_route')|default('')|replace({'.': '-'}) }}" x-data="{ cartOpen: false }" :class="{ 'overflow-hidden': cartOpen }" @keydown.esc.window="cartOpen = false" @menu-open-cart.window="cartOpen = true">
{{ component('tracking:Scripts', { position: 'body' }) }}

{% block header %}
    {{ component('announcement:Banner') }}
    <header id="header" class="theme-header-nav-simple">
        {% include 'partials/_nav.html.twig' %}
        {% block page_hero %}{% endblock %}
    </header>
{% endblock %}

<main id="main" class="relative w-full overflow-hidden">
    {% block main %}{% block content %}{% endblock %}{% endblock %}
</main>

{% block footer %}
    <footer id="footer">
        <twig:site:Footer />
    </footer>
{% endblock %}

{% block mobile_bottom_bar %}{% endblock %}
{% include 'shop/partials/cart.html.twig' %}
{{ component('announcement:Modal') }}
{{ component('modal:SimpleModalDegressivity') }}
{{ component('modal:SimpleModalAward') }}
{{ component('modal:SimpleModalProductDetail') }}
{{ component('modal:SimpleModalProductReviews') }}
{{ component('modal:ShopInformation') }}
{{ include('partials/notifier.html.twig') }}
</body>
</html>
