{% extends 'base.html.twig' %}

{% block title %}{{ 'security.register_confirm.title'|trans({}, 'meta') }}{% endblock %}

{% block meta %}
    <meta name="robots" content="noindex,nofollow">
    <meta name="description" lang="{{ app.request.locale }}" content="{{ 'security.register_confirm.description'|trans({}, 'meta') }}">
{% endblock meta %}

{% block main %}
    <section id="account-auth" class="theme-page theme-auth-page">
        <turbo-frame id="account-auth-frame" class="theme-auth-frame" data-turbo-action="advance">
            <div class="theme-container">
                <article class="theme-auth-card theme-auth-card--single">
                    <div class="theme-auth-card__heading">
                        <p class="theme-eyebrow">{{ 'security.register.submit'|trans }}</p>
                        <h2>{{ 'security.register_confirm.heading'|trans }}</h2>
                        <p>{{ 'security.register_confirm.intro'|trans }}</p>
                    </div>
                    {{ component('security:RegisterConfirmForm', {
                        email: pending_email,
                        marketingOptIn: pending_marketing_opt_in
                    }) }}
                </article>
            </div>
        </turbo-frame>
    </section>
{% endblock %}
