<div {{ attributes.defaults({ 'data-review-opt-out': '', class: 'theme-review-opt-out' }) }}>
    {% if saved %}
        <div data-review-opt-out-status class="theme-review-status theme-review-status--success" role="status">
            {{ 'marketing.review.opt_out.saved'|trans }}
        </div>
    {% elseif this.alreadyOptedOut %}
        <div data-review-opt-out-status class="theme-review-status" role="status">
            {{ 'marketing.review.opt_out.already_saved'|trans }}
        </div>
    {% else %}
        <button
            class="theme-button-fill"
            type="button"
            data-action="live#action"
            data-live-action-param="confirmOptOut"
            data-loading="addAttribute(disabled)"
        >
            {{ 'marketing.review.opt_out.confirm'|trans }}
        </button>
    {% endif %}
</div>
