{% extends '@viti_core_default/cgv.html.twig' %}

{% block page_hero %}
    {% set hero_image_path %}{% block hero_image %}{{ viti_theme_asset('images/headers/header-legal.jpg') }}{% endblock %}{% endset %}
    {% include 'partials/_hero.html.twig' with {
        page_key: 'cgv',
        target_id: 'main',
        image: 'images/headers/header-legal.jpg',
        image_path: hero_image_path|trim,
        image_alt: 'background-header.cgv'
    } %}
{% endblock %}

{% block main %}
    <div class="theme-legal">
        {{ parent() }}
    </div>
{% endblock %}
