{% extends 'base.html.twig' %}

{% block title %}{{ 'marketing.review.form.page_title'|trans }}{% endblock %}

{% block meta %}
    <meta name="robots" content="noindex,nofollow,noarchive">
    <meta name="referrer" content="no-referrer">
{% endblock %}

{% block header %}
    {{ component('announcement:Banner') }}
{% endblock %}

{% block main %}
    <header class="theme-product-header">
        {% include 'partials/_nav.html.twig' %}
    </header>
    <section data-review-invitation-page class="theme-review-page">
        <div class="theme-container theme-review-page__container">
            <header class="theme-review-page__header">
                <p class="theme-eyebrow">{{ 'marketing.review.form.verified_purchase'|trans }}</p>
                <h1>{{ 'marketing.review.form.heading'|trans }}</h1>
                <p>{{ 'marketing.review.form.intro'|trans }}</p>
            </header>

            <twig:marketing:ProductReviewForm :token="token" />

            <p class="theme-review-page__footer-link">
                <a href="{{ path('shop_review_policy') }}">{{ 'marketing.review.policy.link'|trans }}</a>
            </p>
        </div>
    </section>
{% endblock %}
