{% form_theme form with app_form_themes() only %}
{% set selectedVariant = this.selectedVariant %}
{% set selectedOption = this.selectedOption %}
{% set hasSingleVariant = form.variant.vars.choices|length == 1 %}
{% set hasOptionField = form.option is defined %}
{% set hasQuantityField = form.quantity is defined %}
{% set galleryImages = this.galleryImages %}
{% set visibleAwards = this.visibleAwards %}
{% set primaryImage = galleryImages[0] ?? null %}
{% set productImagePath = primaryImage and primaryImage.path ? primaryImage.path : (product.secondImage and product.secondImage.path ? product.secondImage.path : product.image.path) %}
{% set isProductSoldOut = this.productOutOfStock %}
{% set showVariantAvailabilityIndicators = this.shouldShowSelectedVariantAvailabilityIndicators %}
{% set showVariantLimitedStockIndicator = this.shouldShowSelectedVariantLimitedStockIndicator %}
{% set isVariantUnavailable = this.selectedVariantOutOfStock %}
{% set canAddToCart = not isProductSoldOut and not isVariantUnavailable and hasQuantityField %}
{% set showPrices = this.shouldShowPrices %}
{% set orderingDisabledForVacation = this.orderingDisabledForVacation %}
{% set vacationAt = this.vacationAt %}
{% set rawAccentColor = product.color ?: '#AD9C76' %}
{% set accentColor = rawAccentColor starts with('#') ? rawAccentColor : '#' ~ rawAccentColor %}
{% set nameColor = '#ffffff' %}
{% set qualityColor = '#d3ad74' %}

<div data-theme-product-detail {{ attributes.defaults({ class: 'space-y-10' }) }}>
    {{ form_start(form, {'attr' : { 'class': 'space-y-10', 'data-model': 'on(change)|*', 'data-action' : 'live#action:prevent', 'data-live-action-param' : 'debounce(300)|save', 'data-cart-add-form': 'true', 'novalidate': 'true' }}) }}

    <div class="overflow-hidden border border-secondary/35 bg-surface-container-low shadow-[0_28px_80px_rgba(0,0,0,0.42)]">
        <div class="theme-product-detail-grid grid gap-10 px-5 py-6 md:grid-cols-[minmax(0,0.82fr)_minmax(0,1.18fr)] md:gap-6 md:px-8 md:py-8 xl:grid-cols-[minmax(20rem,0.82fr)_minmax(0,1.18fr)] xl:gap-14 xl:px-12 xl:py-12">
            <div class="relative z-10">
                <div class="absolute inset-x-6 top-1/2 h-[52%] -translate-y-1/2 blur-[60px] opacity-40" style="background: radial-gradient(circle, {{ accentColor }} 0%, transparent 72%);"></div>
                <div class="absolute inset-x-0 bottom-6 h-[20%] blur-[40px] opacity-20" style="background: radial-gradient(circle, {{ accentColor }} 0%, transparent 78%);"></div>

                {% if galleryImages|length > 1 %}
                    <div
                        class="grid gap-6 lg:grid-cols-[5rem_minmax(0,1fr)]"
                        data-controller="shop-product-gallery"
                    >
                        <div class="theme-product-gallery-thumbnails lg:order-1">
                            <div
                                class="flex gap-3 overflow-x-auto lg:flex-col"
                                aria-label="{{ 'theme.shop.gallery.thumbnails'|trans }}"
                            >
                                {% for galleryImage in galleryImages %}
                                    <button
                                        type="button"
                                        class="shop-product-gallery-thumb flex h-16 w-16 shrink-0 cursor-pointer items-center justify-center border border-secondary/25 bg-surface-container-high p-2 transition-opacity duration-200 hover:opacity-100 focus-visible:outline-2 focus-visible:outline-offset-2 focus-visible:outline-secondary lg:h-20 lg:w-20"
                                        data-shop-product-gallery-target="thumbnail"
                                        data-action="shop-product-gallery#selectThumbnail"
                                        data-shop-product-gallery-index-param="{{ loop.index0 }}"
                                        aria-label="{{ 'theme.shop.gallery.show_image'|trans({ '%position%': loop.index, '%total%': galleryImages|length }) }}"
                                        {% if loop.first %}aria-current="true"{% endif %}
                                    >
                                        <twig:Image
                                            alt="{{ product.name|striptags }}"
                                            class="h-full w-full"
                                            img:class="h-full w-full object-contain"
                                            lazy="{{ false }}"
                                            quality="{{ 60 }}"
                                            responsive="{{ false }}"
                                            path="{{ galleryImage.path }}"
                                            imageWidth="{{ galleryImage.width ?: 200 }}"
                                            imageHeight="{{ galleryImage.height ?: 200 }}"
                                        />
                                    </button>
                                {% endfor %}
                            </div>
                        </div>

                        <div class="theme-product-gallery-main-wrap order-1 relative z-10 lg:order-2">
                            <div class="absolute top-2 left-0 z-20 flex max-w-[calc(100%-1rem)] flex-col gap-2">
                                {% if product.ribbonCustom %}
                                    {% set rawRibbonColor = product.ribbonCustomColor ?: '#AD9C76' %}
                                    {% set ribbonColor = rawRibbonColor starts with('#') ? rawRibbonColor : '#' ~ rawRibbonColor %}
                                    <div class="px-4 py-2 font-label text-[10px] font-semibold uppercase tracking-[0.18em] text-white shadow-lg" style="background-color: {{ ribbonColor }};">
                                        {{ product.ribbonCustom|raw }}
                                    </div>
                                {% endif %}
                                {% if product.new %}
                                    <div class="px-4 py-2 font-label text-[10px] font-semibold uppercase tracking-[0.18em] text-white shadow-lg" style="background-color: {{ accentColor }};">
                                        {{ 'shop.new'|trans }}
                                    </div>
                                {% endif %}
                                {% if showVariantLimitedStockIndicator and this.selectedVariantLimitedStock and not isProductSoldOut and not isVariantUnavailable %}
                                    <div class="bg-secondary px-4 py-2 font-label text-[10px] font-semibold uppercase tracking-[0.18em] text-[#141414] shadow-lg">
                                        {{ 'shop.limited_quantity'|trans }}
                                    </div>
                                {% endif %}
                                {% if isProductSoldOut %}
                                    <div class="bg-secondary px-4 py-2 font-label text-[10px] font-semibold uppercase tracking-[0.18em] text-[#141414] shadow-lg">
                                        {{ 'cart.outofstock'|trans }}
                                    </div>
                                {% endif %}
                                {% if showVariantAvailabilityIndicators and isVariantUnavailable and not isProductSoldOut %}
                                    <div class="bg-secondary px-4 py-2 font-label text-[10px] font-semibold uppercase tracking-[0.18em] text-[#141414] shadow-lg">
                                        {{ 'shop.variant_outofstock'|trans }}
                                    </div>
                                {% endif %}
                            </div>

                            <div
                                class="product-gallery shop-product-gallery-main splide h-[28rem] sm:h-[36rem] xl:h-[44rem]"
                                data-shop-product-gallery-target="main"
                                aria-label="{{ 'theme.shop.gallery.label'|trans }}"
                            >
                                <div class="splide__track">
                                    <ul class="splide__list h-full">
                                        {% for galleryImage in galleryImages %}
                                            <li class="splide__slide h-full">
                                                <div class="shop-product-gallery-stage flex h-full items-center justify-center overflow-hidden px-6 py-8 sm:px-10">
                                                    <twig:Image
                                                        mapping="image"
                                                        responsive="{{ false }}"
                                                        path="{{ galleryImage.path }}"
                                                        alt="{{ product.name|striptags }}"
                                                        imageWidth="960"
                                                        imageHeight="1320"
                                                        fit="contain"
                                                        quality="{{ 75 }}"
                                                        lazy="{{ false }}"
                                                        class="h-full w-full"
                                                        row:class="flex h-full w-full items-center justify-center"
                                                        row:style="width: 100%; height: 100%; max-width: 100%;"
                                                        img:class="mx-auto block h-full max-h-[44rem] w-auto max-w-full object-contain"
                                                    />
                                                </div>
                                            </li>
                                        {% endfor %}
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                {% elseif productImagePath %}
                    <div class="relative z-10">
                        <div class="absolute top-2 left-0 z-20 flex max-w-[calc(100%-1rem)] flex-col gap-2">
                            {% if product.ribbonCustom %}
                                {% set rawRibbonColor = product.ribbonCustomColor ?: '#AD9C76' %}
                                {% set ribbonColor = rawRibbonColor starts with('#') ? rawRibbonColor : '#' ~ rawRibbonColor %}
                                <div class="px-4 py-2 font-label text-[10px] font-semibold uppercase tracking-[0.18em] text-white shadow-lg" style="background-color: {{ ribbonColor }};">
                                    {{ product.ribbonCustom|raw }}
                                </div>
                            {% endif %}
                            {% if product.new %}
                                <div class="px-4 py-2 font-label text-[10px] font-semibold uppercase tracking-[0.18em] text-white shadow-lg" style="background-color: {{ accentColor }};">
                                    {{ 'shop.new'|trans }}
                                </div>
                            {% endif %}
                            {% if showVariantLimitedStockIndicator and this.selectedVariantLimitedStock and not isProductSoldOut and not isVariantUnavailable %}
                                <div class="bg-secondary px-4 py-2 font-label text-[10px] font-semibold uppercase tracking-[0.18em] text-[#141414] shadow-lg">
                                    {{ 'shop.limited_quantity'|trans }}
                                </div>
                            {% endif %}
                            {% if isProductSoldOut %}
                                <div class="bg-secondary px-4 py-2 font-label text-[10px] font-semibold uppercase tracking-[0.18em] text-[#141414] shadow-lg">
                                    {{ 'cart.outofstock'|trans }}
                                </div>
                            {% endif %}
                            {% if showVariantAvailabilityIndicators and isVariantUnavailable and not isProductSoldOut %}
                                <div class="bg-secondary px-4 py-2 font-label text-[10px] font-semibold uppercase tracking-[0.18em] text-[#141414] shadow-lg">
                                    {{ 'shop.variant_outofstock'|trans }}
                                </div>
                            {% endif %}
                        </div>

                        <div class="shop-product-gallery-stage flex h-[28rem] items-center justify-center overflow-hidden px-6 py-8 sm:h-[36rem] sm:px-10 xl:h-[44rem]">
                            <twig:Image
                                mapping="image"
                                responsive="{{ false }}"
                                path="{{ productImagePath }}"
                                alt="{{ product.name|striptags }}"
                                imageWidth="960"
                                imageHeight="960"
                                fit="contain"
                                quality="{{ 75 }}"
                                lazy="{{ false }}"
                                class="h-full w-full"
                                row:class="flex h-full w-full items-center justify-center"
                                row:style="width: 100%; height: 100%; max-width: 100%;"
                                img:class="mx-auto block h-full max-h-[44rem] w-auto max-w-full object-contain"
                            />
                        </div>
                    </div>
                {% endif %}

                {% if visibleAwards|length > 0 %}
                    <div class="mt-6 flex flex-wrap items-center gap-4 border-t border-primary/10 pt-5">
                        {% for award in visibleAwards %}
                            {% if award.image and award.image.path %}
                                <button
                                    type="button"
                                    class="block w-20 cursor-pointer transition hover:scale-105"
                                    data-action="live#action"
                                    data-live-action-param="showAwardModal"
                                    data-live-award-id-param="{{ award.id.toString }}"
                                >
                                    <twig:Image
                                        alt="{{ award.title ?? product.name|striptags }}"
                                        class="w-20"
                                        img:class="h-full w-full object-contain"
                                        lazy="{{ false }}"
                                        quality="{{ 60 }}"
                                        responsive="{{ false }}"
                                        path="{{ award.image.path }}"
                                        imageWidth="200"
                                        imageHeight="200"
                                    />
                                </button>
                            {% endif %}
                        {% endfor %}
                    </div>
                {% endif %}
            </div>

            <div class="flex flex-col gap-8">
                <div class="space-y-5">
                    {% if product.header %}
                        <div class="font-label text-[12px] font-semibold uppercase tracking-[0.24em] text-secondary">
                            {{ product.header|raw }}
                        </div>
                    {% endif %}

                    <div class="space-y-3">
                        <h1 class="font-display text-[34px] leading-[0.98] font-semibold [font-optical-sizing:auto] md:text-[44px] xl:text-[52px]" style="color: {{ nameColor }};">
                            {{ product.name|raw }}
                        </h1>

                        {% if product.quality %}
                            <div class="font-label text-[12px] font-semibold uppercase tracking-[0.24em]" style="color: {{ qualityColor }};">
                                {{ product.quality|raw }}
                            </div>
                        {% endif %}

                        {% if product.otherText1 %}
                            <div class="text-[18px] leading-8 text-primary/85">
                                {{ product.otherText1 }}
                            </div>
                        {% endif %}
                    </div>

                    {% if product.introText %}
                        <div class="max-w-3xl text-[19px] leading-9 text-primary/78 [&_p]:my-0">
                            {{ product.introText|raw }}
                        </div>
                    {% endif %}

                    {% if product.description %}
                        <div class="max-w-3xl text-[17px] leading-8 text-primary/72 [&_p]:mt-0 [&_p]:mb-5 [&_p:last-child]:mb-0">
                            {{ product.description|raw }}
                        </div>
                    {% endif %}
                </div>

                {% set hasTechBlocks = product.assemblages is not empty or product.dosage or product.tasting or product.winemaking is not empty %}
                {% if hasTechBlocks %}
                    <div class="grid gap-5 md:grid-cols-2 xl:grid-cols-3">
                        {% if product.assemblages is not empty %}
                            <section class="border-t border-primary/20 pt-4">
                                <h2 class="font-display text-[22px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
                                    {{ 'shop.product.section_assemblage'|trans }}
                                </h2>
                                <div class="mt-4 space-y-1 text-[16px] leading-7 text-primary/72">
                                    {% for assemblage in product.assemblages %}
                                        <div>{{ assemblage|raw }}</div>
                                    {% endfor %}
                                </div>
                            </section>
                        {% endif %}

                        {% if product.dosage %}
                            <section class="border-t border-primary/20 pt-4 md:col-span-2 xl:col-span-3">
                                <h2 class="font-display text-[22px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
                                    {{ 'collection.champagne.dosage'|trans }}
                                </h2>
                                <div class="mt-4 text-[16px] leading-7 text-primary/72">
                                    {{ product.dosage|raw }}
                                </div>
                            </section>
                        {% endif %}

                        {% if product.tasting %}
                            <section class="border-t border-primary/20 pt-4">
                                <h2 class="font-display text-[22px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
                                    {{ 'shop.product.section_tasting'|trans }}
                                </h2>
                                <div class="mt-4 text-[16px] leading-7 text-primary/72 [&_p]:mt-0 [&_p]:mb-3 [&_p:last-child]:mb-0">
                                    {{ product.tasting|raw }}
                                </div>
                            </section>
                        {% endif %}

                        {% if product.winemaking is not empty %}
                            <section class="border-t border-primary/20 pt-4">
                                <h2 class="font-display text-[22px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
                                    {{ 'shop.product.section_winemaking'|trans }}
                                </h2>
                                <div class="mt-4 space-y-2 text-[16px] leading-7 text-primary/72">
                                    {% for winemaking in product.winemaking %}
                                        <div>{{ winemaking|raw }}</div>
                                    {% endfor %}
                                </div>
                            </section>
                        {% endif %}
                    </div>
                {% endif %}

                {% if showPrices %}
                    <div class="border border-secondary/25 bg-surface-container-high p-4 shadow-[0_18px_50px_rgba(0,0,0,0.3)] backdrop-blur-sm md:p-5">
                    {% set variant = selectedVariant %}
                    {% set price = variant.getVariantPriceByGroupAvailable %}
                    {% set optionPrice = selectedOption ? selectedOption.price : 0 %}
                    {% set displayPrice = (price.getPrice ?: 0) + optionPrice %}
                    {% set displayDiscountPrice = price.getPriceDiscount ? price.getPriceDiscount + optionPrice : null %}
                    {% set discountPrice = displayDiscountPrice ? displayDiscountPrice|price_format : null %}

                    <div class="flex flex-col gap-5">
                        <div class="flex flex-col gap-3 sm:flex-row sm:items-end sm:justify-between">
                            <div>
                                <div class="font-label text-[10px] font-semibold uppercase tracking-[0.16em] text-secondary">
                                    {{ 'shop.price'|trans }}
                                </div>
                                <div class="mt-1.5 flex flex-wrap items-end gap-2.5">
                                    {% if discountPrice %}
                                        <span class="text-[15px] text-primary/35 line-through decoration-1">
                                            {{ displayPrice|price_format }} €
                                        </span>
                                        <span class="font-display text-[28px] leading-none font-semibold [font-optical-sizing:auto] text-primary md:text-[32px]">
                                            {{ discountPrice }} €
                                        </span>
                                    {% else %}
                                        <span class="font-display text-[28px] leading-none font-semibold [font-optical-sizing:auto] text-primary md:text-[32px]">
                                            {{ displayPrice|price_format }} €
                                        </span>
                                    {% endif %}
                                </div>
                            </div>

                            {% if this.selectedVariantHasDegressive %}
                                <button
                                    type="button"
                                    class="w-fit cursor-pointer font-label text-[10px] font-semibold uppercase tracking-[0.16em] text-secondary underline underline-offset-4 transition hover:text-primary"
                                    data-action="live#action"
                                    data-live-action-param="showDegressiveModal"
                                    {% if selectedVariant %}data-live-variant-id-param="{{ selectedVariant.id }}"{% endif %}
                                >
                                    {{ 'shop.degressive_link'|trans() }}
                                </button>
                            {% endif %}
                        </div>

                        {% if isProductSoldOut %}
                            <div class="border border-primary/10 bg-primary/5 px-4 py-3 text-center font-label text-[10px] font-semibold uppercase tracking-[0.16em] text-primary">
                                {{ 'cart.outofstock'|trans }}
                            </div>
                        {% else %}
                            <div class="space-y-4">
                                <div class="grid gap-4 lg:grid-cols-[minmax(0,1fr)_10rem] xl:grid-cols-[minmax(0,1fr)_11rem]">
                                    <div>
                                        {% if not hasSingleVariant %}
                                            <label class="mb-1.5 block font-label text-[10px] font-semibold uppercase tracking-[0.16em] text-primary/55">
                                                {{ product.selectVariant ?: ('shop.select_volume'|trans) }}
                                            </label>
                                        {% endif %}

                                        {% if hasSingleVariant %}
                                            {{ form_widget(form.variant, {'attr' : {'class' : 'hidden'}}) }}
                                            <div class="min-h-[42px] pt-2 text-[17px] leading-tight text-primary">
                                                {{ selectedVariant ? selectedVariant.label : '' }}
                                            </div>
                                        {% else %}
                                            <div class="relative">
                                                {{ form_widget(form.variant, {'attr' : {'class' : 'min-h-[44px] w-full cursor-pointer appearance-none border border-secondary/35 bg-background px-3 pr-10 text-[15px] text-primary outline-none transition focus:border-secondary'}}) }}
                                                <span class="pointer-events-none absolute inset-y-0 right-3 flex items-center text-primary/55">
                                                    <span aria-hidden="true" class="material-symbols-outlined text-[20px]">expand_more</span>
                                                </span>
                                            </div>
                                        {% endif %}
                                    </div>

                                    <div>
                                        <label class="mb-1.5 block font-label text-[10px] font-semibold uppercase tracking-[0.16em] text-primary/55">
                                            {{ 'shop.quantity'|trans }}
                                        </label>

                                        {% if (showVariantAvailabilityIndicators and isVariantUnavailable) or not hasQuantityField %}
                                            <div class="flex min-h-[44px] items-center justify-center border border-primary/10 bg-primary/5 px-4 text-center text-[14px] text-primary">
                                                {{ 'shop.variant_outofstock'|trans }}
                                            </div>
                                        {% else %}
                                            <div data-controller="quantity-stepper" class="w-full">
                                                {{ form_widget(form.quantity, {
                                                    attr : {
                                                        'class' : 'hidden',
                                                        'inputmode': 'numeric',
                                                        'data-model': 'norender|' ~ form.quantity.vars.full_name,
                                                        'data-quantity-stepper-target': 'input',
                                                        'data-action': 'input->quantity-stepper#syncDisplay change->quantity-stepper#syncDisplay'
                                                    }
                                                }) }}
                                                <div class="flex h-[44px] items-center justify-between border border-secondary/35 bg-background px-1.5">
                                                    <button
                                                        type="button"
                                                        class="flex h-[40px] w-9 cursor-pointer items-center justify-center text-[24px] leading-none text-primary"
                                                        data-action="quantity-stepper#decrement"
                                                        aria-label="{{ 'shop.quantity'|trans }} -"
                                                    >
                                                        -
                                                    </button>
                                                    <span
                                                        class="flex min-w-9 items-center justify-center px-2 text-[16px] text-primary"
                                                        data-quantity-stepper-target="display"
                                                    >
                                                        {{ form.quantity.vars.value ?: 1 }}
                                                    </span>
                                                    <button
                                                        type="button"
                                                        class="flex h-[40px] w-9 cursor-pointer items-center justify-center text-[24px] leading-none text-primary"
                                                        data-action="quantity-stepper#increment"
                                                        aria-label="{{ 'shop.quantity'|trans }} +"
                                                    >
                                                        +
                                                    </button>
                                                </div>
                                            </div>
                                        {% endif %}
                                    </div>
                                </div>

                                {% if orderingDisabledForVacation %}
                                    <div class="border border-secondary/25 bg-background px-4 py-3 text-center text-[15px] leading-7 text-primary">
                                        {{ 'shop.reopening_at'|trans({ '%date%': vacationAt|format_datetime('long', 'short', locale: app.request.locale) }) }}
                                    </div>
                                {% else %}
                                    <button
                                        type="submit"
                                        data-cart-add-trigger
                                        class="{% if canAddToCart %}cursor-pointer bg-secondary text-[#141414] hover:bg-secondary-fixed{% else %}cursor-not-allowed bg-primary/15 text-primary/45{% endif %} inline-flex min-h-[46px] w-full items-center justify-center px-4 py-3 font-label text-[10px] font-semibold uppercase tracking-[0.18em] transition"
                                        {% if not canAddToCart %}disabled aria-disabled="true"{% endif %}
                                    >
                                        {{ 'cart.add_button'|trans() }}
                                    </button>
                                {% endif %}
                            </div>
                        {% endif %}
                    </div>
                    </div>
                {% else %}
                    <div class="border border-secondary/25 bg-surface-container-high p-5 text-center text-[15px] leading-7 text-primary shadow-[0_18px_50px_rgba(0,0,0,0.3)] backdrop-blur-sm">
                        {% if orderingDisabledForVacation %}
                            {{ 'shop.reopening_at'|trans({ '%date%': vacationAt|format_datetime('long', 'short', locale: app.request.locale) }) }}
                        {% else %}
                            {{ 'shop.view_with_partner_code'|trans }}
                        {% endif %}
                    </div>
                {% endif %}
            </div>
        </div>
    </div>

    {% if product.file or product.infoShop %}
        <div class="grid gap-6 lg:grid-cols-3">
            {% if product.infoShop %}
                <section class="border border-secondary/25 bg-surface px-6 py-6 shadow-[0_16px_40px_rgba(0,0,0,0.3)] {% if product.file %}lg:col-span-1{% else %}lg:col-span-2{% endif %}">
                    <h2 class="font-display text-[28px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
                        {{ 'shop.product.section_info_shop'|trans }}
                    </h2>
                    <div class="mt-4 text-[16px] leading-7 text-primary/72 [&_p]:mt-0 [&_p]:mb-4 [&_p:last-child]:mb-0">
                        {{ product.infoShop|raw }}
                    </div>
                </section>
            {% endif %}

            {% if product.file %}
                <section class="border border-secondary/25 bg-surface px-6 py-6 shadow-[0_16px_40px_rgba(0,0,0,0.3)]">
                    <h2 class="font-display text-[28px] leading-tight font-semibold [font-optical-sizing:auto] text-primary">
                        {{ 'shop.product.section_documents'|trans }}
                    </h2>
                    <div class="mt-4">
                        <a
                            href="{{ product.file.path|file_path }}"
                            target="_blank"
                            class="inline-flex min-h-[48px] items-center justify-center border border-secondary bg-secondary px-6 py-3 font-label text-[11px] font-semibold uppercase tracking-[0.18em] text-[#141414] transition hover:border-secondary-fixed hover:bg-secondary-fixed"
                        >
                            {{ 'collection.champagne.file'|trans()|raw }}
                        </a>
                    </div>
                </section>
            {% endif %}
        </div>
    {% endif %}

    {% if not form.variant.isRendered() %}
        {{ form_widget(form.variant, { attr: { class: 'hidden' } }) }}
    {% endif %}
    {% if form.quantity is defined and not form.quantity.isRendered() %}
        {{ form_widget(form.quantity, { attr: { class: 'hidden' } }) }}
    {% endif %}
    {% if form.option is defined and not form.option.isRendered() %}
        {{ form_widget(form.option, { attr: { class: 'hidden' } }) }}
    {% endif %}
    {% if form._token is defined and not form._token.isRendered() %}
        {{ form_widget(form._token) }}
    {% endif %}
    {{ form_end(form, { render_rest: false }) }}
</div>
