{% set mailLocale = locale|default('fr') %}
<!DOCTYPE html>
<html lang="{{ mailLocale }}">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{{ 'withdrawal.mail.customer.heading'|trans({}, 'messages', mailLocale) }}</title>
    <style>
        @media only screen and (max-width: 640px) {
            .theme-email-shell { padding: 16px 8px !important; }
            .theme-email-header, .theme-email-body { padding-right: 22px !important; padding-left: 22px !important; }
            .theme-email-title { font-size: 26px !important; }
        }
    </style>
</head>
<body style="margin:0; padding:0; background:#141414; color:#ffffff; font-family:Arial, Helvetica, sans-serif;">
<table role="presentation" width="100%" cellspacing="0" cellpadding="0" style="width:100%; margin:0; padding:0; background:#141414;">
    <tr>
        <td class="theme-email-shell" align="center" style="padding:36px 16px;">
            <table role="presentation" width="640" cellspacing="0" cellpadding="0" style="width:100%; max-width:640px; border:1px solid #6f5a3b; background:#252524;">
                <tr>
                    <td class="theme-email-header" style="padding:40px 40px 30px; border-bottom:1px solid #6f5a3b; background:#3c3c3b; text-align:center;">
                        {% if contact and contact.image and contact.image.path %}
                            <img src="{{ absolute_url(asset(contact.image.path)|imagine_filter('logo_email_filter')) }}" alt="{{ contact.image.title ?: company }}" width="180" style="display:block; width:100%; max-width:180px; height:auto; margin:0 auto 24px;">
                        {% endif %}
                        <div style="color:#d3ad74; font-size:11px; font-weight:700; letter-spacing:0.2em; text-transform:uppercase;">{{ company }}</div>
                        <h1 class="theme-email-title" style="margin:16px 0 0; color:#ffffff; font-family:Georgia, 'Times New Roman', serif; font-size:32px; font-weight:400; line-height:1.25;">{{ 'withdrawal.mail.customer.heading'|trans({}, 'messages', mailLocale) }}</h1>
                    </td>
                </tr>
                <tr>
                    <td class="theme-email-body" style="padding:32px 40px 40px; color:#e7e2da; font-size:15px; line-height:1.7;">
                        <p style="margin:0 0 24px;">{{ 'withdrawal.mail.customer.intro'|trans({}, 'messages', mailLocale) }}</p>

                        {% include 'mail/_withdrawal_summary.html.twig' with {
                            locale: mailLocale,
                            withdrawal_request: withdrawal_request
                        } only %}

                        <p style="margin:24px 0 0; border-left:3px solid #d3ad74; padding:14px 16px; background:#30302f; color:#ffffff;">{{ 'withdrawal.mail.customer.next_steps'|trans({}, 'messages', mailLocale) }}</p>
                    </td>
                </tr>
            </table>
        </td>
    </tr>
</table>
</body>
</html>
