{% set blockedDisabledCountry = null %}
{% if blockedCountryCode %}
    {% for disabledCountry in config.disableCountries %}
        {% if disabledCountry.country == blockedCountryCode %}
            {% set blockedDisabledCountry = disabledCountry %}
        {% endif %}
    {% endfor %}
{% endif %}

<section class="theme-shop-blocked" role="alert" aria-labelledby="shop-blocked-title">
    <div class="theme-shop-blocked__icon" aria-hidden="true">
        <svg viewBox="0 0 24 24" focusable="false">
            <circle cx="12" cy="12" r="8.5" />
            <path d="M3.8 12h16.4M12 3.5c2 2.3 3.1 5.2 3.1 8.5S14 18.2 12 20.5M12 3.5C10 5.8 8.9 8.7 8.9 12s1.1 6.2 3.1 8.5" />
        </svg>
    </div>

    <div class="theme-shop-blocked__content">
        <p class="theme-shop-blocked__eyebrow">{{ 'shop.title'|trans }}</p>
        <h2 id="shop-blocked-title">
            {{ 'shop.blockShop'|trans({'%country%': blockedCountryCode|country_name}) }}
        </h2>

        {% if blockedDisabledCountry and blockedDisabledCountry.description|default('')|striptags|trim is not empty %}
            <div class="theme-shop-blocked__description">
                {{ blockedDisabledCountry.description|raw }}
            </div>
        {% endif %}

        <div class="theme-shop-blocked__contact">
            <p>{{ 'shop.blockShopContact'|trans }}</p>
            <a href="{{ path('contact') }}" class="theme-button-fill theme-hover-link-effect">
                {{ 'shop.blockShopContactLink'|trans }}
            </a>
        </div>
    </div>
</section>
