{% extends 'layout/checkout.html.twig' %}

{% block title %}{{ 'checkout_design.payment_pending_title'|trans }}{% endblock %}

{% block meta %}
    {% set payment_pending_parameters = { cartId: cart.id, startedAt: started_at } %}
    {% if stripe_session_id %}
        {% set payment_pending_parameters = payment_pending_parameters|merge({ stripeSessionId: stripe_session_id }) %}
    {% endif %}
    <meta http-equiv="refresh" content="3;url={{ path('shop_checkout_payment_pending', payment_pending_parameters) }}">
    <meta name="robots" content="noindex,nofollow">
{% endblock meta %}

{% block main %}
    <section class="theme-checkout-status">
        <div class="theme-checkout-status__card">
            <div class="theme-checkout-spinner" aria-hidden="true"></div>
            <p class="theme-checkout-eyebrow">{{ 'checkout_design.payment_pending_badge'|trans }}</p>
            <h1>{{ 'checkout_design.payment_pending_title'|trans }}</h1>
            <p>{{ 'checkout_design.payment_pending_notice'|trans }}</p>
            <p class="theme-checkout-status__reference">
                {{ 'checkout_design.payment_pending_reference'|trans({ '%reference%': cart.token }) }}
            </p>
        </div>
    </section>
{% endblock %}
