{% extends 'base.html.twig' %}

{% block title %}{{ 'security.login.title'|trans({}, 'meta') }}{% endblock %}

{% block meta %}
    {{ include('partials/seo.html.twig', {
        title_key: 'security.login.title',
        description_key: 'security.login.description',
        robots: 'noindex,nofollow'
    }) }}
{% endblock meta %}

{% block main %}
    <section id="account-auth" class="theme-page theme-auth-page">
        <turbo-frame id="account-auth-frame" class="theme-auth-frame" data-turbo-action="advance">
            <div class="theme-container">
                <div class="theme-auth-grid">
                    <article class="theme-auth-card">
                        <div class="theme-auth-card__heading">
                            <p class="theme-eyebrow">{{ 'security.login.title'|trans }}</p>
                            <h2>{{ 'security.login.submit'|trans }}</h2>
                        </div>
                        {{ component('security:LoginForm', {
                            targetPath: app.request.get('_target_path')
                        }) }}
                    </article>

                    <article class="theme-auth-card theme-auth-card--muted">
                        <div class="theme-auth-card__heading">
                            <p class="theme-eyebrow">{{ 'security.register.submit'|trans }}</p>
                            <h2>{{ 'security.register.submit'|trans }}</h2>
                        </div>
                        {{ component('security:RegisterForm') }}
                    </article>
                </div>
            </div>
        </turbo-frame>
    </section>
{% endblock %}
