{% set variant = variant|default('panel') %}
{% set top = top|default(false) %}

<twig:Image
    mapping="public"
    class="theme-picture theme-home-picture theme-home-picture--{{ variant }}{% if top %} theme-home-picture--top{% endif %}"
    alt="{{ alt }}"
    lazy="{{ false }}"
    picture:style="width: 100%; height: 100%;"
    path="{{ viti_theme_asset(image) }}"
    pathLandscape="{{ viti_theme_asset(image) }}"
    ratio="3/2"
    imageWidth="1200"
    imageHeight="800"
/>
