<div {{ attributes.defaults({ class: 'theme-container theme-shop-layout' }) }}>
    <div class="theme-shop-product-detail__header">
        <a
            href="{{ path('shop') }}"
            class="theme-button-stroke theme-hover-link-effect">
            {{ 'shop.product.back_to_shop'|trans }}
        </a>

        <div>
            <h1 class="theme-shop-heading">{{ product.name|raw }}</h1>
            {% if product.quality %}
                <div class="theme-shop-product-detail__quality">{{ product.quality|raw }}</div>
            {% endif %}
        </div>
    </div>

    <div class="theme-shop-product-detail__body">
        {{ component('shop:ProductDetailForm', { product: product }) }}
        {{ component('shop:LegalNotice') }}
    </div>
</div>
