<table role="presentation" width="100%" cellspacing="0" cellpadding="0" style="width:100%; border:1px solid #6f5a3b; border-collapse:collapse;">
    <tr>
        <td width="42%" style="padding:12px 16px; border-bottom:1px solid #554a3a; background:#252524; color:#d3ad74; font-weight:700; vertical-align:top;">{{ 'withdrawal.summary.name'|trans({}, 'messages', locale) }}</td>
        <td style="padding:12px 16px; border-bottom:1px solid #554a3a; background:#3c3c3b; color:#ffffff; vertical-align:top;">{{ withdrawal_request.firstname }} {{ withdrawal_request.lastname }}</td>
    </tr>
    <tr>
        <td width="42%" style="padding:12px 16px; border-bottom:1px solid #554a3a; background:#252524; color:#d3ad74; font-weight:700; vertical-align:top;">{{ 'withdrawal.summary.reference'|trans({}, 'messages', locale) }}</td>
        <td style="padding:12px 16px; border-bottom:1px solid #554a3a; background:#3c3c3b; color:#ffffff; vertical-align:top;">{{ withdrawal_request.contractReference }}</td>
    </tr>
    <tr>
        <td width="42%" style="padding:12px 16px; border-bottom:1px solid #554a3a; background:#252524; color:#d3ad74; font-weight:700; vertical-align:top;">{{ 'withdrawal.summary.email'|trans({}, 'messages', locale) }}</td>
        <td style="padding:12px 16px; border-bottom:1px solid #554a3a; background:#3c3c3b; color:#ffffff; word-break:break-word; vertical-align:top;">{{ withdrawal_request.receiptEmail }}</td>
    </tr>
    <tr>
        <td width="42%" style="padding:12px 16px; border-bottom:1px solid #554a3a; background:#252524; color:#d3ad74; font-weight:700; vertical-align:top;">{{ 'withdrawal.summary.order_received'|trans({}, 'messages', locale) }}</td>
        <td style="padding:12px 16px; border-bottom:1px solid #554a3a; background:#3c3c3b; color:#ffffff; vertical-align:top;">{{ (withdrawal_request.orderReceived is same as(true) ? 'withdrawal.form.yes' : (withdrawal_request.orderReceived is same as(false) ? 'withdrawal.form.no' : 'withdrawal.form.not_provided'))|trans({}, 'messages', locale) }}</td>
    </tr>
    {% if withdrawal_request.orderReceived and withdrawal_request.receivedAt %}
        <tr>
            <td width="42%" style="padding:12px 16px; border-bottom:1px solid #554a3a; background:#252524; color:#d3ad74; font-weight:700; vertical-align:top;">{{ 'withdrawal.summary.received_at'|trans({}, 'messages', locale) }}</td>
            <td style="padding:12px 16px; border-bottom:1px solid #554a3a; background:#3c3c3b; color:#ffffff; vertical-align:top;">{{ withdrawal_request.receivedAt|date('d/m/Y') }}</td>
        </tr>
    {% endif %}
    {% if withdrawal_request.reasonCode %}
        <tr>
            <td width="42%" style="padding:12px 16px; border-bottom:1px solid #554a3a; background:#252524; color:#d3ad74; font-weight:700; vertical-align:top;">{{ 'withdrawal.summary.reason'|trans({}, 'messages', locale) }}</td>
            <td style="padding:12px 16px; border-bottom:1px solid #554a3a; background:#3c3c3b; color:#ffffff; vertical-align:top;">{{ ('withdrawal.reason.' ~ withdrawal_request.reasonCode)|trans({}, 'messages', locale) }}</td>
        </tr>
    {% endif %}
    {% if withdrawal_request.comment %}
        <tr>
            <td width="42%" style="padding:12px 16px; border-bottom:1px solid #554a3a; background:#252524; color:#d3ad74; font-weight:700; vertical-align:top;">{{ 'withdrawal.summary.comment'|trans({}, 'messages', locale) }}</td>
            <td style="padding:12px 16px; border-bottom:1px solid #554a3a; background:#3c3c3b; color:#ffffff; vertical-align:top;">{{ withdrawal_request.comment|nl2br }}</td>
        </tr>
    {% endif %}
    <tr>
        <td width="42%" style="padding:12px 16px; background:#252524; color:#d3ad74; font-weight:700; vertical-align:top;">{{ 'withdrawal.summary.submitted_at'|trans({}, 'messages', locale) }}</td>
        <td style="padding:12px 16px; background:#3c3c3b; color:#ffffff; vertical-align:top;">{{ withdrawal_request.submittedAt|date('d/m/Y H:i:s T') }}</td>
    </tr>
</table>
