{% if contact.committeeChampagneSiret or contact.committeeChampagneIdentifiant %}
    <section class="theme-legal-block">
        <h2>{{ 'legal_pages.agec.title'|trans }}</h2>
        <p>{{ 'legal_pages.agec.intro'|trans }}</p>
        <ul>
            {% if contact.committeeChampagneSiret %}
                <li>{{ 'legal_pages.agec.committee_champagne_siret'|trans({ '%value%': contact.committeeChampagneSiret }) }}</li>
            {% endif %}
            {% if contact.committeeChampagneIdentifiant %}
                <li>{{ 'legal_pages.agec.committee_champagne_identifier'|trans({ '%value%': contact.committeeChampagneIdentifiant }) }}</li>
            {% endif %}
        </ul>
    </section>
{% endif %}
