{% extends 'base.html.twig' %}

{% block title %}{{ 'payment.title'|trans({}, 'meta') }}{% endblock %}

{% block meta %}
    {{ include('partials/seo.html.twig', {
        title_key: 'payment.title',
        description_key: 'payment.description',
        robots: 'noindex,follow'
    }) }}
{% endblock meta %}

{% block header %}{% endblock %}

{% block main %}
    <header class="theme-product-header">
        {% include 'partials/_nav.html.twig' %}
    </header>

    <section class="theme-page theme-auth-page theme-payment-page">
        <div class="theme-container">
            <twig:payment:Form :paymentId="app.request.attributes.get('id')" />
        </div>
    </section>
{% endblock %}
