{% extends '@viti_core_default/shop/index.html.twig' %}

{% block page_hero %}
    {% set hero_image_path %}{% block hero_image %}{{ viti_theme_asset('images/headers/header-shop.jpg') }}{% endblock %}{% endset %}
    {% include 'partials/_hero.html.twig' with {
        page_key: 'shop',
        target_id: 'shop-content',
        image: 'images/headers/header-shop.jpg',
        image_path: hero_image_path|trim,
        image_alt: 'background-header.shop'
    } %}
{% endblock %}

{% block main %}
    <section id="shop" class="theme-page theme-shop-page">
        <twig:shop:Catalog />
    </section>
{% endblock %}

{% block mobile_bottom_bar %}
    <twig:shop:CatalogMobileBar />
{% endblock %}
